@@ -14,4 +14,5 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-from pm4py.algo.analysis.woflan import algorithm
+from pm4py.algo.analysis.woflan import algorithm, graphs, not_well_handled_pairs, place_invariants
+
