@@ -23,6 +23,11 @@ from collections import Counter
 from pm4py.util import exec_utils, constants, xes_constants
 from enum import Enum
 from pm4py.util import variants_util
+from typing import Optional, Dict, Any, Union, Tuple
+from pm4py.objects.log.obj import EventLog, EventStream
+import pandas as pd
+from pm4py.objects.petri_net.obj import PetriNet, Marking
+from pm4py.util import typing
 
 
 class Parameters(Enum):
@@ -266,7 +271,7 @@ def tr_vlist(vlist, net, im, fm, tmap, bmap, parameters=None):
             "enabled_transitions_in_marking": enabled_transitions_in_marking}
 
 
-def apply(log, net, initial_marking, final_marking, parameters=None):
+def apply(log: EventLog, net: PetriNet, initial_marking: Marking, final_marking: Marking, parameters: Optional[Dict[Union[str, Parameters], Any]] = None) -> typing.ListAlignments:
     """
     Method to apply token-based replay
 
@@ -328,7 +333,7 @@ def apply(log, net, initial_marking, final_marking, parameters=None):
     return ret
 
 
-def get_diagnostics_dataframe(log, tbr_output, parameters=None):
+def get_diagnostics_dataframe(log: EventLog, tbr_output: typing.ListAlignments, parameters: Optional[Dict[Union[str, Parameters], Any]] = None) -> pd.DataFrame:
     """
     Gets the results of token-based replay in a dataframe
 
