@@ -17,9 +17,6 @@
 import copy
 from typing import List, Optional, Set, Dict
 
-import networkx as nx
-from networkx.classes.graph import Graph
-
 from pm4py.algo.discovery.inductive.variants.im_clean import utils as im_utils
 from pm4py.algo.discovery.inductive.variants.im_clean.d_types import Cut, DFG
 from pm4py.objects.log.obj import EventLog, Trace
@@ -65,14 +62,15 @@ def detect(dfg: DFG, alphabet: Dict[str, int], start_activities: Dict[str, int],
 
     groups = _exclude_sets_non_reachable_from_start(dfg, start_activities, end_activities, groups)
     groups = _exclude_sets_no_reachable_from_end(dfg, start_activities, end_activities, groups)
-    groups = _check_start_end_completeness(dfg, start_activities, end_activities, groups)
+    groups = _check_start_completeness(dfg, start_activities, end_activities, groups)
+    groups = _check_end_completeness(dfg, start_activities, end_activities, groups)
 
     groups = list(filter(lambda g: len(g) > 0, groups))
 
     return groups if len(groups) > 1 else None
 
 
-def _check_start_end_completeness(dfg, start_activities, end_activities, groups):
+def _check_start_completeness(dfg, start_activities, end_activities, groups):
     i = 1
     while i < len(groups):
         merge = False
@@ -84,6 +82,21 @@ def _check_start_end_completeness(dfg, start_activities, end_activities, groups)
                     for s in start_activities:
                         if not (a, s) in dfg:
                             merge = True
+        if merge:
+            groups[0] = groups[0].union(groups[i])
+            del groups[i]
+            continue
+        i = i + 1
+    return groups
+
+
+def _check_end_completeness(dfg, start_activities, end_activities, groups):
+    i = 1
+    while i < len(groups):
+        merge = False
+        for a in groups[i]:
+            if merge:
+                break
             for (b, x) in dfg:
                 if x == a and b in end_activities:
                     for e in end_activities:
@@ -127,10 +140,11 @@ def _exclude_sets_no_reachable_from_end(dfg: DFG, start_activities: Dict[str, in
 
 
 def _compute_connected_components(dfg: DFG, alphabet: Set[str], start_activities: Dict[str, int],
-                                  end_activities: Dict[str, int], do_set: Set[str]) -> List[Graph]:
+                                  end_activities: Dict[str, int], do_set: Set[str]):
+    import networkx as nx
     reduced_dfg = copy.copy(dfg)
     for (a, b) in dfg:
-        if a in end_activities or a in end_activities or b in start_activities or b in end_activities:
+        if a in start_activities or a in end_activities or b in start_activities or b in end_activities:
             del reduced_dfg[(a, b)]
     reduced_alphabet = set(alphabet).difference(do_set)
     nx_directed = im_utils.transform_dfg_to_directed_nx_graph(reduced_dfg, reduced_alphabet)
@@ -176,3 +190,38 @@ def _append_trace_to_redo_log(redo_trace: Trace, redo_logs: List[List[Trace]], r
     inte = sorted(inte, key=lambda x: (x[1], x[0]), reverse=True)
     redo_logs[inte[0][0]].append(redo_trace)
     return redo_logs
+
+
+def project_dfg(dfg_sa_ea_actcount, groups):
+    dfgs = []
+    skippable = [False, False]
+    for gind, g in enumerate(groups):
+        activities = {}
+        start_activities = {}
+        end_activities = {}
+        paths_frequency = {}
+        for act in dfg_sa_ea_actcount.act_count:
+            if act in g:
+                activities[act] = dfg_sa_ea_actcount.act_count[act]
+        for arc in dfg_sa_ea_actcount.dfg:
+            if arc[0] in g and arc[1] in g:
+                paths_frequency[arc] = dfg_sa_ea_actcount.dfg[arc]
+            if arc[1] in dfg_sa_ea_actcount.start_activities and arc[0] in dfg_sa_ea_actcount.end_activities:
+                skippable[1] = True
+        if gind == 0:
+            for act in dfg_sa_ea_actcount.start_activities:
+                if act in g:
+                    start_activities[act] = dfg_sa_ea_actcount.start_activities[act]
+                else:
+                    skippable[0] = True
+            for act in dfg_sa_ea_actcount.end_activities:
+                if act in g:
+                    end_activities[act] = dfg_sa_ea_actcount.end_activities[act]
+                else:
+                    skippable[1] = True
+        elif gind == 1:
+            for act in g:
+                start_activities[act] = 1
+                end_activities[act] = 1
+        dfgs.append(im_utils.DfgSaEaActCount(paths_frequency, start_activities, end_activities, activities))
+    return [dfgs, skippable]
