@@ -18,11 +18,14 @@ from pm4py.algo.filtering.common import filtering_constants
 from pm4py.util.constants import CASE_CONCEPT_NAME
 from pm4py.statistics.traces.generic.pandas import case_statistics
 from pm4py.statistics.traces.generic.pandas.case_statistics import get_variants_df
+from pm4py.statistics.variants.pandas import get as variants_get
 from pm4py.util.constants import PARAMETER_CONSTANT_CASEID_KEY, PARAMETER_CONSTANT_ACTIVITY_KEY
 from enum import Enum
 from pm4py.util import exec_utils
 from copy import copy
 import deprecation
+from typing import Optional, Dict, Any, Union, Tuple, List
+import pandas as pd
 
 
 class Parameters(Enum):
@@ -76,7 +79,7 @@ def apply_auto_filter(df, parameters=None):
     return apply(df, admitted_variants, parameters=parameters)
 
 
-def apply(df, admitted_variants, parameters=None):
+def apply(df: pd.DataFrame, admitted_variants: List[List[str]], parameters: Optional[Dict[Union[str, Parameters], Any]] = None) -> pd.DataFrame:
     """
     Apply a filter on variants
 
@@ -116,3 +119,67 @@ def apply(df, admitted_variants, parameters=None):
 
     ret.attrs = copy(df.attrs) if hasattr(df, 'attrs') else {}
     return ret
+
+
+def filter_variants_top_k(log, k, parameters=None):
+    """
+    Keeps the top-k variants of the log
+
+    Parameters
+    -------------
+    log
+        Event log
+    k
+        Number of variants that should be kept
+    parameters
+        Parameters
+
+    Returns
+    -------------
+    filtered_log
+        Filtered log
+    """
+    if parameters is None:
+        parameters = {}
+
+    variants = variants_get.get_variants_count(log, parameters=parameters)
+    variant_count = []
+    for variant in variants:
+        variant_count.append([variant, variants[variant]])
+    variant_count = sorted(variant_count, key=lambda x: (x[1], x[0]), reverse=True)
+    variant_count = variant_count[:min(k, len(variant_count))]
+    variants_to_filter = [x[0] for x in variant_count]
+
+    return apply(log, variants_to_filter, parameters=parameters)
+
+
+def filter_variants_by_coverage_percentage(log, min_coverage_percentage, parameters=None):
+    """
+    Filters the variants of the log by a coverage percentage
+    (e.g., if min_coverage_percentage=0.4, and we have a log with 1000 cases,
+    of which 500 of the variant 1, 400 of the variant 2, and 100 of the variant 3,
+    the filter keeps only the traces of variant 1 and variant 2).
+
+    Parameters
+    ---------------
+    log
+        Event log
+    min_coverage_percentage
+        Minimum allowed percentage of coverage
+    parameters
+        Parameters
+
+    Returns
+    ---------------
+    filtered_log
+        Filtered log
+    """
+    if parameters is None:
+        parameters = {}
+
+    case_id_glue = exec_utils.get_param_value(Parameters.CASE_ID_KEY, parameters, CASE_CONCEPT_NAME)
+
+    variants = variants_get.get_variants_count(log, parameters=parameters)
+    allowed_variants = [x for x, y in variants.items() if y >= min_coverage_percentage * log[case_id_glue].nunique()]
+
+    return apply(log, allowed_variants, parameters=parameters)
