@@ -19,12 +19,13 @@ from typing import List, Dict, Any, Union
 
 import deprecation
 
-from pm4py.objects.log.obj import EventLog, Trace, Event
+from pm4py.objects.log.obj import EventLog, Trace, Event, EventStream
 from pm4py.objects.petri_net.obj import PetriNet, Marking
 from collections import Counter
 from pm4py.objects.process_tree.obj import ProcessTree
 from pm4py.util import xes_constants
-from pm4py.utils import get_properties, general_checks_classical_event_log
+from pm4py.utils import get_properties
+import pandas as pd
 
 
 @deprecation.deprecated(deprecated_in='2.2.2', removed_in='2.4.0',
@@ -52,7 +53,8 @@ def conformance_tbr(log: EventLog, petri_net: PetriNet, initial_marking: Marking
     replay_results
         A list of replay results for each trace of the log
     """
-    general_checks_classical_event_log(log)
+    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
+
     from pm4py.algo.conformance.tokenreplay import algorithm as token_replay
     return token_replay.apply(log, petri_net, initial_marking, final_marking, parameters=get_properties(log))
 
@@ -79,7 +81,8 @@ def conformance_diagnostics_token_based_replay(log: EventLog, petri_net: PetriNe
     replay_results
         A list of replay results for each trace of the log (in the same order as the traces in the event log)
     """
-    general_checks_classical_event_log(log)
+    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
+
     from pm4py.algo.conformance.tokenreplay import algorithm as token_replay
     return token_replay.apply(log, petri_net, initial_marking, final_marking, parameters=get_properties(log))
 
@@ -103,7 +106,8 @@ def conformance_diagnostics_alignments(log: EventLog, *args, multi_processing: b
     aligned_traces
         A list of alignments for each trace of the log (in the same order as the traces in the event log)
     """
-    general_checks_classical_event_log(log)
+    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
+
     if len(args) == 3:
         if type(args[0]) is PetriNet:
             # Petri net alignments
@@ -159,7 +163,8 @@ def conformance_alignments(log: EventLog, petri_net: PetriNet, initial_marking:
     aligned_traces
         A list of alignments for each trace of the log
     """
-    general_checks_classical_event_log(log)
+    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
+
     from pm4py.algo.conformance.alignments.petri_net import algorithm as alignments
     return alignments.apply(log, petri_net, initial_marking, final_marking, parameters=get_properties(log))
 
@@ -188,7 +193,8 @@ def fitness_token_based_replay(log: EventLog, petri_net: PetriNet, initial_marki
     fitness_dictionary
         dictionary describing average fitness (key: average_trace_fitness) and the percentage of fitting traces (key: percentage_of_fitting_traces)
     """
-    general_checks_classical_event_log(log)
+    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
+
     from pm4py.algo.evaluation.replay_fitness import algorithm as replay_fitness
     return replay_fitness.apply(log, petri_net, initial_marking, final_marking,
                                 variant=replay_fitness.Variants.TOKEN_BASED, parameters=get_properties(log))
@@ -219,7 +225,8 @@ def evaluate_fitness_tbr(log: EventLog, petri_net: PetriNet, initial_marking: Ma
     fitness_dictionary
         Fitness dictionary (from TBR)
     """
-    general_checks_classical_event_log(log)
+    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
+
     from pm4py.algo.evaluation.replay_fitness import algorithm as replay_fitness
     return replay_fitness.apply(log, petri_net, initial_marking, final_marking,
                                 variant=replay_fitness.Variants.TOKEN_BASED, parameters=get_properties(log))
@@ -248,7 +255,8 @@ def fitness_alignments(log: EventLog, petri_net: PetriNet, initial_marking: Mark
     fitness_dictionary
         dictionary describing average fitness (key: average_trace_fitness) and the percentage of fitting traces (key: percentage_of_fitting_traces)
     """
-    general_checks_classical_event_log(log)
+    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
+
     from pm4py.algo.evaluation.replay_fitness import algorithm as replay_fitness
     parameters = get_properties(log)
     parameters["multiprocessing"] = multi_processing
@@ -280,7 +288,8 @@ def evaluate_fitness_alignments(log: EventLog, petri_net: PetriNet, initial_mark
     fitness_dictionary
         Fitness dictionary (from alignments)
     """
-    general_checks_classical_event_log(log)
+    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
+
     from pm4py.algo.evaluation.replay_fitness import algorithm as replay_fitness
     return replay_fitness.apply(log, petri_net, initial_marking, final_marking,
                                 variant=replay_fitness.Variants.ALIGNMENT_BASED, parameters=get_properties(log))
@@ -307,7 +316,8 @@ def precision_token_based_replay(log: EventLog, petri_net: PetriNet, initial_mar
     precision
         float representing the precision value
     """
-    general_checks_classical_event_log(log)
+    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
+
     from pm4py.algo.evaluation.precision import algorithm as precision_evaluator
     return precision_evaluator.apply(log, petri_net, initial_marking, final_marking,
                                      variant=precision_evaluator.Variants.ETCONFORMANCE_TOKEN, parameters=get_properties(log))
@@ -337,7 +347,8 @@ def evaluate_precision_tbr(log: EventLog, petri_net: PetriNet, initial_marking:
     precision
         float representing the precision value
     """
-    general_checks_classical_event_log(log)
+    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
+
     from pm4py.algo.evaluation.precision import algorithm as precision_evaluator
     return precision_evaluator.apply(log, petri_net, initial_marking, final_marking,
                                      variant=precision_evaluator.Variants.ETCONFORMANCE_TOKEN, parameters=get_properties(log))
@@ -366,7 +377,8 @@ def precision_alignments(log: EventLog, petri_net: PetriNet, initial_marking: Ma
     precision
         float representing the precision value
     """
-    general_checks_classical_event_log(log)
+    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
+
     from pm4py.algo.evaluation.precision import algorithm as precision_evaluator
     parameters = get_properties(log)
     parameters["multiprocessing"] = multi_processing
@@ -399,7 +411,8 @@ def evaluate_precision_alignments(log: EventLog, petri_net: PetriNet, initial_ma
     precision
         float representing the precision value
     """
-    general_checks_classical_event_log(log)
+    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
+
     from pm4py.algo.evaluation.precision import algorithm as precision_evaluator
     return precision_evaluator.apply(log, petri_net, initial_marking, final_marking,
                                      variant=precision_evaluator.Variants.ALIGN_ETCONFORMANCE, parameters=get_properties(log))
