@@ -19,9 +19,14 @@ import tempfile
 import numpy as np
 
 from ortools.linear_solver import pywraplp
-from pm4py.util.lp.parameters import Parameters
 from pm4py.util import exec_utils
 
+from enum import Enum
+
+
+class Parameters(Enum):
+    REQUIRE_ILP = "require_ilp"
+
 
 MIN_THRESHOLD = 10 ** -12
 
