@@ -29,6 +29,7 @@ from enum import Enum
 from pm4py.util import constants
 from typing import Optional, Dict, Any, Tuple
 from pm4py.objects.log.obj import EventLog
+from collections import Counter
 
 
 class Parameters(Enum):
@@ -130,9 +131,8 @@ def get_activities_color(activities_count):
 
 
 def graphviz_visualization(activities_count, dfg, image_format="png", measure="frequency",
-                           max_no_of_edges_in_diagram=100000, start_activities=None, 
-                           end_activities=None, soj_time=None, font_size="12", 
-                           bgcolor="transparent", stat_locale: dict = None):
+                           max_no_of_edges_in_diagram=100000, start_activities=None, end_activities=None, soj_time=None,
+                            font_size="12", bgcolor=constants.DEFAULT_BGCOLOR, stat_locale=None):
     """
     Do GraphViz visualization of a DFG graph
 
@@ -286,10 +286,8 @@ def apply(dfg: Dict[Tuple[str, str], int], log: EventLog = None, parameters: Opt
     font_size = exec_utils.get_param_value(Parameters.FONT_SIZE, parameters, 12)
     font_size = str(font_size)
     activities = dfg_utils.get_activities_from_dfg(dfg)
-    bgcolor = exec_utils.get_param_value(Parameters.BGCOLOR, parameters, "transparent")
-    stat_locale = exec_utils.get_param_value(Parameters.STAT_LOCALE, parameters, None)
-    if stat_locale is None:
-        stat_locale = {}
+    bgcolor = exec_utils.get_param_value(Parameters.BGCOLOR, parameters, constants.DEFAULT_BGCOLOR)
+    stat_locale = exec_utils.get_param_value(Parameters.STAT_LOCALE, parameters, {})
 
     if activities_count is None:
         if log is not None:
@@ -298,7 +296,7 @@ def apply(dfg: Dict[Tuple[str, str], int], log: EventLog = None, parameters: Opt
             # the frequency of an activity in the log is at least the number of occurrences of
             # incoming arcs in the DFG.
             # if the frequency of the start activities nodes is also provided, use also that.
-            activities_count = {key: 0 for key in activities}
+            activities_count = Counter({key: 0 for key in activities})
             for el in dfg:
                 activities_count[el[1]] += dfg[el]
             if isinstance(start_activities, dict):
