@@ -27,9 +27,11 @@ from pm4py.util import exec_utils
 from pm4py.statistics.sojourn_time.log import get as soj_time_get
 from pm4py.util import constants
 from enum import Enum
+from collections import Counter
 
 from typing import Optional, Dict, Any, Tuple
 from pm4py.objects.log.obj import EventLog
+from collections import Counter
 
 
 class Parameters(Enum):
@@ -163,9 +165,8 @@ def get_edges_color(duration_list: list) -> str:
     return edges_color
 
 def graphviz_visualization(activities_count, dfg, image_format="png", measure="frequency",
-                           max_no_of_edges_in_diagram=100000, start_activities=None, 
-                           end_activities=None, soj_time=None, font_size="12", 
-                           bgcolor="transparent", stat_locale: dict = None):
+                           max_no_of_edges_in_diagram=100000, start_activities=None, end_activities=None, soj_time=None,
+                           font_size="12", bgcolor=constants.DEFAULT_BGCOLOR, stat_locale=None):
     """
     Do GraphViz visualization of a DFG graph
 
@@ -328,12 +329,22 @@ def apply(dfg: Dict[Tuple[str, str], int], log: EventLog = None, parameters: Opt
     font_size = str(font_size)
     activities = dfg_utils.get_activities_from_dfg(dfg)
     aggregation_measure = exec_utils.get_param_value(Parameters.AGGREGATION_MEASURE, parameters, "mean")
-    bgcolor = exec_utils.get_param_value(Parameters.BGCOLOR, parameters, "transparent")
-    stat_locale = exec_utils.get_param_value(Parameters.STAT_LOCALE, parameters, None)
-
-    if stat_locale is None:
-        stat_locale = {}
+    bgcolor = exec_utils.get_param_value(Parameters.BGCOLOR, parameters, constants.DEFAULT_BGCOLOR)
+    stat_locale = exec_utils.get_param_value(Parameters.STAT_LOCALE, parameters, {})
 
+    # if all the aggregation measures are provided for a given key,
+    # then pick one of the values for the representation
+    dfg0 = dfg
+    dfg = {}
+    for key in dfg0:
+        try:
+            if aggregation_measure in dfg0[key]:
+                dfg[key] = dfg0[key][aggregation_measure]
+            else:
+                dfg[key] = dfg0[key]
+        except:
+            dfg[key] = dfg0[key]
+    
     if activities_count is None:
         if log is not None:
             activities_count = attr_get.get_attribute_values(log, activity_key, parameters=parameters)
@@ -354,21 +365,8 @@ def apply(dfg: Dict[Tuple[str, str], int], log: EventLog = None, parameters: Opt
         else:
             soj_time = {key: -1 for key in activities}
 
-    # if all the aggregation measures are provided for a given key,
-    # then pick one of the values for the representation
-    dfg0 = dfg
-    dfg = {}
-    for key in dfg0:
-        try:
-            if aggregation_measure in dfg0[key]:
-                dfg[key] = dfg0[key][aggregation_measure]
-            else:
-                dfg[key] = dfg0[key]
-        except:
-            dfg[key] = dfg0[key]
-
     return graphviz_visualization(activities_count, dfg, image_format=image_format, measure="performance",
                                   max_no_of_edges_in_diagram=max_no_of_edges_in_diagram,
                                   start_activities=start_activities, end_activities=end_activities, 
-                                  soj_time=soj_time, font_size=font_size, bgcolor=bgcolor, 
-                                  stat_locale=stat_locale)
+                                  soj_time=soj_time, font_size=font_size, bgcolor=bgcolor, stat_locale=stat_locale)
+
